
divewidgets
=====================================

Version: |release|

Jupyter Widgets for DIVE virtual learning environment.


Quickstart
----------

To get started with divewidgets, install with pip::

    pip install divewidgets

or with conda::

    conda install divewidgets


Contents
--------

.. toctree::
   :maxdepth: 2
   :caption: Installation and usage

   installing
   introduction

.. toctree::
   :maxdepth: 1

   examples/index


.. toctree::
   :maxdepth: 2
   :caption: Development

   develop-install


.. links

.. _`Jupyter widgets`: https://jupyter.org/widgets.html

.. _`notebook`: https://jupyter-notebook.readthedocs.io/en/latest/
